@@ -1,8 +1,7 @@
-import numpy as np
-import pytest
-
 from pathlib import Path
 
+import numpy as np
+import pytest
 from steinbock import io
 from steinbock.segmentation import deepcell
 from steinbock.segmentation.deepcell import Application
@@ -15,7 +14,7 @@ class TestDeepcellSegmentation:
     @pytest.mark.skip(reason="Test would take too long")
     @pytest.mark.filterwarnings("ignore::DeprecationWarning")
     def test_try_segment_objects_mesmer(self, imc_test_data_steinbock_path: Path):
-        from tensorflow.keras.models import load_model
+        from tensorflow.keras.models import load_model  # type: ignore
 
         img_files = io.list_image_files(imc_test_data_steinbock_path / "img")
         model = None
